You are viewing a plain text version of this content. The canonical link for it is here.
Posted to java-dev@axis.apache.org by ke...@apache.org on 2007/02/05 09:21:19 UTC

svn commit: r503585 [4/9] - in /webservices/axis2/trunk/java: etc/ modules/adb-codegen/ modules/adb-codegen/src/org/apache/axis2/schema/ modules/adb-codegen/src/org/apache/axis2/schema/template/ modules/adb/ modules/addressing/ modules/addressing/src/o...

Modified: webservices/axis2/trunk/java/modules/kernel/src/org/apache/axis2/description/AxisOperationFactory.java
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/java/modules/kernel/src/org/apache/axis2/description/AxisOperationFactory.java?view=diff&rev=503585&r1=503584&r2=503585
==============================================================================
--- webservices/axis2/trunk/java/modules/kernel/src/org/apache/axis2/description/AxisOperationFactory.java (original)
+++ webservices/axis2/trunk/java/modules/kernel/src/org/apache/axis2/description/AxisOperationFactory.java Mon Feb  5 00:21:12 2007
@@ -28,44 +28,44 @@
         AxisOperation abOpdesc;
 
         switch (mepURI) {
-            case WSDL20_2004Constants.MEP_CONSTANT_IN_ONLY : {
+            case WSDLConstants.MEP_CONSTANT_IN_ONLY : {
                 abOpdesc = new InOnlyAxisOperation();
-                abOpdesc.setMessageExchangePattern(WSDL20_2004Constants.MEP_URI_IN_ONLY);
+                abOpdesc.setMessageExchangePattern(WSDL20_2006Constants.MEP_URI_IN_ONLY);
                 break;
             }
-            case WSDL20_2004Constants.MEP_CONSTANT_OUT_ONLY : {
+            case WSDLConstants.MEP_CONSTANT_OUT_ONLY : {
                 abOpdesc = new OutOnlyAxisOperation();
-                abOpdesc.setMessageExchangePattern(WSDL20_2004Constants.MEP_URI_OUT_ONLY);
+                abOpdesc.setMessageExchangePattern(WSDL20_2006Constants.MEP_URI_OUT_ONLY);
                 break;
             }
-            case WSDL20_2004Constants.MEP_CONSTANT_IN_OUT : {
+            case WSDLConstants.MEP_CONSTANT_IN_OUT : {
                 abOpdesc = new InOutAxisOperation();
-                abOpdesc.setMessageExchangePattern(WSDL20_2004Constants.MEP_URI_IN_OUT);
+                abOpdesc.setMessageExchangePattern(WSDL20_2006Constants.MEP_URI_IN_OUT);
                 break;
             }
-            case WSDL20_2004Constants.MEP_CONSTANT_IN_OPTIONAL_OUT : {
+            case WSDLConstants.MEP_CONSTANT_IN_OPTIONAL_OUT : {
                 abOpdesc = new InOutAxisOperation();
-                abOpdesc.setMessageExchangePattern(WSDL20_2004Constants.MEP_URI_IN_OPTIONAL_OUT);
+                abOpdesc.setMessageExchangePattern(WSDL20_2006Constants.MEP_URI_IN_OPTIONAL_OUT);
                 break;
             }
-            case WSDL20_2004Constants.MEP_CONSTANT_ROBUST_IN_ONLY : {
+            case WSDLConstants.MEP_CONSTANT_ROBUST_IN_ONLY : {
                 abOpdesc = new InOutAxisOperation();
-                abOpdesc.setMessageExchangePattern(WSDL20_2004Constants.MEP_URI_ROBUST_IN_ONLY);
+                abOpdesc.setMessageExchangePattern(WSDL20_2006Constants.MEP_URI_ROBUST_IN_ONLY);
                 break;
             }
-            case WSDL20_2004Constants.MEP_CONSTANT_OUT_IN : {
+            case WSDLConstants.MEP_CONSTANT_OUT_IN : {
                 abOpdesc = new OutInAxisOperation();
-                abOpdesc.setMessageExchangePattern(WSDL20_2004Constants.MEP_URI_OUT_IN);
+                abOpdesc.setMessageExchangePattern(WSDL20_2006Constants.MEP_URI_OUT_IN);
                 break;
             }
-            case WSDL20_2004Constants.MEP_CONSTANT_OUT_OPTIONAL_IN : {
+            case WSDLConstants.MEP_CONSTANT_OUT_OPTIONAL_IN : {
                 abOpdesc = new OutInAxisOperation();
-                abOpdesc.setMessageExchangePattern(WSDL20_2004Constants.MEP_URI_OUT_OPTIONAL_IN);
+                abOpdesc.setMessageExchangePattern(WSDL20_2006Constants.MEP_URI_OUT_OPTIONAL_IN);
                 break;
             }
-            case WSDL20_2004Constants.MEP_CONSTANT_ROBUST_OUT_ONLY : {
+            case WSDLConstants.MEP_CONSTANT_ROBUST_OUT_ONLY : {
                 abOpdesc = new RobustOutOnlyAxisOperation();
-                abOpdesc.setMessageExchangePattern(WSDL20_2004Constants.MEP_URI_ROBUST_OUT_ONLY);
+                abOpdesc.setMessageExchangePattern(WSDL20_2006Constants.MEP_URI_ROBUST_OUT_ONLY);
                 break;
             }
             default : {
@@ -75,26 +75,34 @@
         return abOpdesc;
     }
 
-    //FIXME add in the latest MEP URIs
+    //FIXME add in the latest MEP URIs AND needs to double check on about the mep we had in 2004
     public static AxisOperation getOperationDescription(String mepURI) throws AxisFault {
         AxisOperation abOpdesc;
-        if (WSDL20_2004Constants.MEP_URI_IN_ONLY.equals(mepURI) || WSDL20_2006Constants.MEP_URI_IN_ONLY.equals(mepURI)) {
+        if (WSDL20_2006Constants.MEP_URI_IN_ONLY.equals(mepURI) ||
+                WSDL20_2004_Constants.MEP_URI_IN_ONLY.equals(mepURI)) {
             abOpdesc = new InOnlyAxisOperation();
-        } else if (WSDL20_2004Constants.MEP_URI_OUT_ONLY.equals(mepURI) || WSDL20_2006Constants.MEP_URI_OUT_ONLY.equals(mepURI)) {
+        } else if (WSDL20_2006Constants.MEP_URI_OUT_ONLY.equals(mepURI) ||
+                WSDL20_2004_Constants.MEP_URI_OUT_ONLY.equals(mepURI)) {
             abOpdesc = new OutOnlyAxisOperation();
-        } else if (WSDL20_2004Constants.MEP_URI_IN_OUT.equals(mepURI) || WSDL20_2004Constants.MEP_URI_IN_OUT_03.equals(mepURI) || WSDL20_2006Constants.MEP_URI_IN_OUT.equals(mepURI)) {
+        } else if (WSDL20_2006Constants.MEP_URI_IN_OUT.equals(mepURI) ||
+                WSDL20_2004_Constants.MEP_URI_IN_OUT.equals(mepURI)) {
             abOpdesc = new InOutAxisOperation();
-        } else if (WSDL20_2004Constants.MEP_URI_IN_OPTIONAL_OUT.equals(mepURI) || WSDL20_2006Constants.MEP_URI_IN_OPTIONAL_OUT.equals(mepURI)) {
+        } else if (WSDL20_2006Constants.MEP_URI_IN_OPTIONAL_OUT.equals(mepURI) ||
+                WSDL20_2004_Constants.MEP_URI_IN_OPTIONAL_OUT.equals(mepURI)) {
             abOpdesc = new InOutAxisOperation();
-        } else if (WSDL20_2004Constants.MEP_URI_OUT_IN.equals(mepURI) || WSDL20_2006Constants.MEP_URI_OUT_IN.equals(mepURI)) {
+        } else if (WSDL20_2006Constants.MEP_URI_OUT_IN.equals(mepURI) ||
+                WSDL20_2004_Constants.MEP_URI_OUT_IN.equals(mepURI)) {
             abOpdesc = new OutInAxisOperation();
-        } else if (WSDL20_2004Constants.MEP_URI_OUT_OPTIONAL_IN.equals(mepURI) || WSDL20_2006Constants.MEP_URI_OUT_OPTIONAL_IN.equals(mepURI)) {
+        } else if (WSDL20_2006Constants.MEP_URI_OUT_OPTIONAL_IN.equals(mepURI) ||
+                WSDL20_2004_Constants.MEP_URI_OUT_OPTIONAL_IN.equals(mepURI)) {
             abOpdesc = new OutInAxisOperation();
-        } else if (WSDL20_2004Constants.MEP_URI_ROBUST_OUT_ONLY.equals(mepURI) || WSDL20_2006Constants.MEP_URI_ROBUST_OUT_ONLY.equals(mepURI)) {
+        } else if (WSDL20_2006Constants.MEP_URI_ROBUST_OUT_ONLY.equals(mepURI) ||
+                WSDL20_2004_Constants.MEP_URI_ROBUST_OUT_ONLY.equals(mepURI)) {
             abOpdesc = new OutInAxisOperation();
-        } else if (WSDL20_2004Constants.MEP_URI_ROBUST_IN_ONLY.equals(mepURI) || WSDL20_2006Constants.MEP_URI_ROBUST_IN_ONLY.equals(mepURI)) {
+        } else if (WSDL20_2006Constants.MEP_URI_ROBUST_IN_ONLY.equals(mepURI) ||
+                WSDL20_2004_Constants.MEP_URI_ROBUST_IN_ONLY.equals(mepURI)) {
             abOpdesc = new InOnlyAxisOperation();
-        }else {
+        } else {
             throw new AxisFault(Messages.getMessage("unSupportedMEP", "ID is " + mepURI));
         }
         abOpdesc.setMessageExchangePattern(mepURI);

Modified: webservices/axis2/trunk/java/modules/kernel/src/org/apache/axis2/description/AxisService.java
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/java/modules/kernel/src/org/apache/axis2/description/AxisService.java?view=diff&rev=503585&r1=503584&r2=503585
==============================================================================
--- webservices/axis2/trunk/java/modules/kernel/src/org/apache/axis2/description/AxisService2OM.java (original)
+++ webservices/axis2/trunk/java/modules/kernel/src/org/apache/axis2/description/AxisService2OM.java Mon Feb  5 00:21:12 2007
@@ -243,16 +243,16 @@
                 continue;
             }
             String MEP = axisOperation.getMessageExchangePattern();
-            if (WSDLConstants.WSDL20_2004Constants.MEP_URI_IN_ONLY.equals(MEP)
-                    || WSDLConstants.WSDL20_2004Constants.MEP_URI_IN_OPTIONAL_OUT
+            if (WSDLConstants.WSDL20_2006Constants.MEP_URI_IN_ONLY.equals(MEP)
+                    || WSDLConstants.WSDL20_2006Constants.MEP_URI_IN_OPTIONAL_OUT
                     .equals(MEP)
-                    || WSDLConstants.WSDL20_2004Constants.MEP_URI_OUT_OPTIONAL_IN
+                    || WSDLConstants.WSDL20_2006Constants.MEP_URI_OUT_OPTIONAL_IN
                     .equals(MEP)
-                    || WSDLConstants.WSDL20_2004Constants.MEP_URI_ROBUST_OUT_ONLY
+                    || WSDLConstants.WSDL20_2006Constants.MEP_URI_ROBUST_OUT_ONLY
                     .equals(MEP)
-                    || WSDLConstants.WSDL20_2004Constants.MEP_URI_ROBUST_IN_ONLY
+                    || WSDLConstants.WSDL20_2006Constants.MEP_URI_ROBUST_IN_ONLY
                     .equals(MEP)
-                    || WSDLConstants.WSDL20_2004Constants.MEP_URI_IN_OUT
+                    || WSDLConstants.WSDL20_2006Constants.MEP_URI_IN_OUT
                     .equals(MEP)) {
                 AxisMessage inaxisMessage = axisOperation
                         .getMessage(WSDLConstants.MESSAGE_LABEL_IN_VALUE);
@@ -262,14 +262,14 @@
                 }
             }
 
-            if (WSDLConstants.WSDL20_2004Constants.MEP_URI_OUT_ONLY.equals(MEP)
-                    || WSDLConstants.WSDL20_2004Constants.MEP_URI_OUT_OPTIONAL_IN
+            if (WSDLConstants.WSDL20_2006Constants.MEP_URI_OUT_ONLY.equals(MEP)
+                    || WSDLConstants.WSDL20_2006Constants.MEP_URI_OUT_OPTIONAL_IN
                     .equals(MEP)
-                    || WSDLConstants.WSDL20_2004Constants.MEP_URI_IN_OPTIONAL_OUT
+                    || WSDLConstants.WSDL20_2006Constants.MEP_URI_IN_OPTIONAL_OUT
                     .equals(MEP)
-                    || WSDLConstants.WSDL20_2004Constants.MEP_URI_ROBUST_OUT_ONLY
+                    || WSDLConstants.WSDL20_2006Constants.MEP_URI_ROBUST_OUT_ONLY
                     .equals(MEP)
-                    || WSDLConstants.WSDL20_2004Constants.MEP_URI_IN_OUT
+                    || WSDLConstants.WSDL20_2006Constants.MEP_URI_IN_OUT
                     .equals(MEP)) {
                 AxisMessage outAxisMessage = axisOperation
                         .getMessage(WSDLConstants.MESSAGE_LABEL_OUT_VALUE);
@@ -369,16 +369,16 @@
                     .getPolicyInclude(), operation, fac);
 
             String MEP = axisOperation.getMessageExchangePattern();
-            if (WSDLConstants.WSDL20_2004Constants.MEP_URI_IN_ONLY.equals(MEP)
-                    || WSDLConstants.WSDL20_2004Constants.MEP_URI_IN_OPTIONAL_OUT
+            if (WSDLConstants.WSDL20_2006Constants.MEP_URI_IN_ONLY.equals(MEP)
+                    || WSDLConstants.WSDL20_2006Constants.MEP_URI_IN_OPTIONAL_OUT
                     .equals(MEP)
-                    || WSDLConstants.WSDL20_2004Constants.MEP_URI_OUT_OPTIONAL_IN
+                    || WSDLConstants.WSDL20_2006Constants.MEP_URI_OUT_OPTIONAL_IN
                     .equals(MEP)
-                    || WSDLConstants.WSDL20_2004Constants.MEP_URI_ROBUST_OUT_ONLY
+                    || WSDLConstants.WSDL20_2006Constants.MEP_URI_ROBUST_OUT_ONLY
                     .equals(MEP)
-                    || WSDLConstants.WSDL20_2004Constants.MEP_URI_ROBUST_IN_ONLY
+                    || WSDLConstants.WSDL20_2006Constants.MEP_URI_ROBUST_IN_ONLY
                     .equals(MEP)
-                    || WSDLConstants.WSDL20_2004Constants.MEP_URI_IN_OUT
+                    || WSDLConstants.WSDL20_2006Constants.MEP_URI_IN_OUT
                     .equals(MEP)) {
                 AxisMessage inaxisMessage = axisOperation
                         .getMessage(WSDLConstants.MESSAGE_LABEL_IN_VALUE);
@@ -395,14 +395,14 @@
                 }
             }
 
-            if (WSDLConstants.WSDL20_2004Constants.MEP_URI_OUT_ONLY.equals(MEP)
-                    || WSDLConstants.WSDL20_2004Constants.MEP_URI_OUT_OPTIONAL_IN
+            if (WSDLConstants.WSDL20_2006Constants.MEP_URI_OUT_ONLY.equals(MEP)
+                    || WSDLConstants.WSDL20_2006Constants.MEP_URI_OUT_OPTIONAL_IN
                     .equals(MEP)
-                    || WSDLConstants.WSDL20_2004Constants.MEP_URI_IN_OPTIONAL_OUT
+                    || WSDLConstants.WSDL20_2006Constants.MEP_URI_IN_OPTIONAL_OUT
                     .equals(MEP)
-                    || WSDLConstants.WSDL20_2004Constants.MEP_URI_ROBUST_OUT_ONLY
+                    || WSDLConstants.WSDL20_2006Constants.MEP_URI_ROBUST_OUT_ONLY
                     .equals(MEP)
-                    || WSDLConstants.WSDL20_2004Constants.MEP_URI_IN_OUT
+                    || WSDLConstants.WSDL20_2006Constants.MEP_URI_IN_OUT
                     .equals(MEP)) {
                 AxisMessage outAxisMessage = axisOperation
                         .getMessage(WSDLConstants.MESSAGE_LABEL_OUT_VALUE);
@@ -607,16 +607,16 @@
 
             String MEP = axisOperation.getMessageExchangePattern();
 
-            if (WSDLConstants.WSDL20_2004Constants.MEP_URI_IN_ONLY.equals(MEP)
-                    || WSDLConstants.WSDL20_2004Constants.MEP_URI_IN_OPTIONAL_OUT
+            if (WSDLConstants.WSDL20_2006Constants.MEP_URI_IN_ONLY.equals(MEP)
+                    || WSDLConstants.WSDL20_2006Constants.MEP_URI_IN_OPTIONAL_OUT
                     .equals(MEP)
-                    || WSDLConstants.WSDL20_2004Constants.MEP_URI_OUT_OPTIONAL_IN
+                    || WSDLConstants.WSDL20_2006Constants.MEP_URI_OUT_OPTIONAL_IN
                     .equals(MEP)
-                    || WSDLConstants.WSDL20_2004Constants.MEP_URI_ROBUST_OUT_ONLY
+                    || WSDLConstants.WSDL20_2006Constants.MEP_URI_ROBUST_OUT_ONLY
                     .equals(MEP)
-                    || WSDLConstants.WSDL20_2004Constants.MEP_URI_ROBUST_IN_ONLY
+                    || WSDLConstants.WSDL20_2006Constants.MEP_URI_ROBUST_IN_ONLY
                     .equals(MEP)
-                    || WSDLConstants.WSDL20_2004Constants.MEP_URI_IN_OUT
+                    || WSDLConstants.WSDL20_2006Constants.MEP_URI_IN_OUT
                     .equals(MEP)) {
                 AxisMessage inaxisMessage = axisOperation
                         .getMessage(WSDLConstants.MESSAGE_LABEL_IN_VALUE);
@@ -633,14 +633,14 @@
                 }
             }
 
-            if (WSDLConstants.WSDL20_2004Constants.MEP_URI_OUT_ONLY.equals(MEP)
-                    || WSDLConstants.WSDL20_2004Constants.MEP_URI_OUT_OPTIONAL_IN
+            if (WSDLConstants.WSDL20_2006Constants.MEP_URI_OUT_ONLY.equals(MEP)
+                    || WSDLConstants.WSDL20_2006Constants.MEP_URI_OUT_OPTIONAL_IN
                     .equals(MEP)
-                    || WSDLConstants.WSDL20_2004Constants.MEP_URI_IN_OPTIONAL_OUT
+                    || WSDLConstants.WSDL20_2006Constants.MEP_URI_IN_OPTIONAL_OUT
                     .equals(MEP)
-                    || WSDLConstants.WSDL20_2004Constants.MEP_URI_ROBUST_OUT_ONLY
+                    || WSDLConstants.WSDL20_2006Constants.MEP_URI_ROBUST_OUT_ONLY
                     .equals(MEP)
-                    || WSDLConstants.WSDL20_2004Constants.MEP_URI_IN_OUT
+                    || WSDLConstants.WSDL20_2006Constants.MEP_URI_IN_OUT
                     .equals(MEP)) {
                 AxisMessage outAxisMessage = axisOperation
                         .getMessage(WSDLConstants.MESSAGE_LABEL_OUT_VALUE);
@@ -741,16 +741,16 @@
 
             String MEP = axisOperation.getMessageExchangePattern();
 
-            if (WSDLConstants.WSDL20_2004Constants.MEP_URI_IN_ONLY.equals(MEP)
-                    || WSDLConstants.WSDL20_2004Constants.MEP_URI_IN_OPTIONAL_OUT
+            if (WSDLConstants.WSDL20_2006Constants.MEP_URI_IN_ONLY.equals(MEP)
+                    || WSDLConstants.WSDL20_2006Constants.MEP_URI_IN_OPTIONAL_OUT
                     .equals(MEP)
-                    || WSDLConstants.WSDL20_2004Constants.MEP_URI_OUT_OPTIONAL_IN
+                    || WSDLConstants.WSDL20_2006Constants.MEP_URI_OUT_OPTIONAL_IN
                     .equals(MEP)
-                    || WSDLConstants.WSDL20_2004Constants.MEP_URI_ROBUST_OUT_ONLY
+                    || WSDLConstants.WSDL20_2006Constants.MEP_URI_ROBUST_OUT_ONLY
                     .equals(MEP)
-                    || WSDLConstants.WSDL20_2004Constants.MEP_URI_ROBUST_IN_ONLY
+                    || WSDLConstants.WSDL20_2006Constants.MEP_URI_ROBUST_IN_ONLY
                     .equals(MEP)
-                    || WSDLConstants.WSDL20_2004Constants.MEP_URI_IN_OUT
+                    || WSDLConstants.WSDL20_2006Constants.MEP_URI_IN_OUT
                     .equals(MEP)) {
                 AxisMessage inaxisMessage = axisOperation
                         .getMessage(WSDLConstants.MESSAGE_LABEL_IN_VALUE);
@@ -767,14 +767,14 @@
                 }
             }
 
-            if (WSDLConstants.WSDL20_2004Constants.MEP_URI_OUT_ONLY.equals(MEP)
-                    || WSDLConstants.WSDL20_2004Constants.MEP_URI_OUT_OPTIONAL_IN
+            if (WSDLConstants.WSDL20_2006Constants.MEP_URI_OUT_ONLY.equals(MEP)
+                    || WSDLConstants.WSDL20_2006Constants.MEP_URI_OUT_OPTIONAL_IN
                     .equals(MEP)
-                    || WSDLConstants.WSDL20_2004Constants.MEP_URI_IN_OPTIONAL_OUT
+                    || WSDLConstants.WSDL20_2006Constants.MEP_URI_IN_OPTIONAL_OUT
                     .equals(MEP)
-                    || WSDLConstants.WSDL20_2004Constants.MEP_URI_ROBUST_OUT_ONLY
+                    || WSDLConstants.WSDL20_2006Constants.MEP_URI_ROBUST_OUT_ONLY
                     .equals(MEP)
-                    || WSDLConstants.WSDL20_2004Constants.MEP_URI_IN_OUT
+                    || WSDLConstants.WSDL20_2006Constants.MEP_URI_IN_OUT
                     .equals(MEP)) {
                 AxisMessage outAxisMessage = axisOperation
                         .getMessage(WSDLConstants.MESSAGE_LABEL_OUT_VALUE);
@@ -842,16 +842,16 @@
 
             String MEP = axisOperation.getMessageExchangePattern();
 
-            if (WSDLConstants.WSDL20_2004Constants.MEP_URI_IN_ONLY.equals(MEP)
-                    || WSDLConstants.WSDL20_2004Constants.MEP_URI_IN_OPTIONAL_OUT
+            if (WSDLConstants.WSDL20_2006Constants.MEP_URI_IN_ONLY.equals(MEP)
+                    || WSDLConstants.WSDL20_2006Constants.MEP_URI_IN_OPTIONAL_OUT
                     .equals(MEP)
-                    || WSDLConstants.WSDL20_2004Constants.MEP_URI_OUT_OPTIONAL_IN
+                    || WSDLConstants.WSDL20_2006Constants.MEP_URI_OUT_OPTIONAL_IN
                     .equals(MEP)
-                    || WSDLConstants.WSDL20_2004Constants.MEP_URI_ROBUST_OUT_ONLY
+                    || WSDLConstants.WSDL20_2006Constants.MEP_URI_ROBUST_OUT_ONLY
                     .equals(MEP)
-                    || WSDLConstants.WSDL20_2004Constants.MEP_URI_ROBUST_IN_ONLY
+                    || WSDLConstants.WSDL20_2006Constants.MEP_URI_ROBUST_IN_ONLY
                     .equals(MEP)
-                    || WSDLConstants.WSDL20_2004Constants.MEP_URI_IN_OUT
+                    || WSDLConstants.WSDL20_2006Constants.MEP_URI_IN_OUT
                     .equals(MEP)) {
                 AxisMessage inaxisMessage = axisOperation
                         .getMessage(WSDLConstants.MESSAGE_LABEL_IN_VALUE);
@@ -867,14 +867,14 @@
                 }
             }
 
-            if (WSDLConstants.WSDL20_2004Constants.MEP_URI_OUT_ONLY.equals(MEP)
-                    || WSDLConstants.WSDL20_2004Constants.MEP_URI_OUT_OPTIONAL_IN
+            if (WSDLConstants.WSDL20_2006Constants.MEP_URI_OUT_ONLY.equals(MEP)
+                    || WSDLConstants.WSDL20_2006Constants.MEP_URI_OUT_OPTIONAL_IN
                     .equals(MEP)
-                    || WSDLConstants.WSDL20_2004Constants.MEP_URI_IN_OPTIONAL_OUT
+                    || WSDLConstants.WSDL20_2006Constants.MEP_URI_IN_OPTIONAL_OUT
                     .equals(MEP)
-                    || WSDLConstants.WSDL20_2004Constants.MEP_URI_ROBUST_OUT_ONLY
+                    || WSDLConstants.WSDL20_2006Constants.MEP_URI_ROBUST_OUT_ONLY
                     .equals(MEP)
-                    || WSDLConstants.WSDL20_2004Constants.MEP_URI_IN_OUT
+                    || WSDLConstants.WSDL20_2006Constants.MEP_URI_IN_OUT
                     .equals(MEP)) {
                 AxisMessage outAxisMessage = axisOperation
                         .getMessage(WSDLConstants.MESSAGE_LABEL_OUT_VALUE);

Modified: webservices/axis2/trunk/java/modules/kernel/src/org/apache/axis2/description/InOnlyAxisOperation.java
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/java/modules/kernel/src/org/apache/axis2/description/InOnlyAxisOperation.java?view=diff&rev=503585&r1=503584&r2=503585
==============================================================================
--- webservices/axis2/trunk/java/modules/kernel/src/org/apache/axis2/description/InOnlyAxisOperation.java (original)
+++ webservices/axis2/trunk/java/modules/kernel/src/org/apache/axis2/description/InOnlyAxisOperation.java Mon Feb  5 00:21:12 2007
@@ -41,13 +41,13 @@
         QName tmpName = new QName(this.getClass().getName()+"_"+UUIDGenerator.getUUID());
         this.setName(tmpName);
         createMessage();
-        setMessageExchangePattern(WSDL20_2004Constants.MEP_URI_IN_ONLY);
+        setMessageExchangePattern(WSDL20_2006Constants.MEP_URI_IN_ONLY);
     }
 
     public InOnlyAxisOperation(QName name) {
         super(name);
         createMessage();
-        setMessageExchangePattern(WSDL20_2004Constants.MEP_URI_IN_ONLY);
+        setMessageExchangePattern(WSDL20_2006Constants.MEP_URI_IN_ONLY);
     }
 
     public void addMessage(AxisMessage message, String label) {

Modified: webservices/axis2/trunk/java/modules/kernel/src/org/apache/axis2/description/OutInAxisOperation.java
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/java/modules/kernel/src/org/apache/axis2/description/OutInAxisOperation.java?view=diff&rev=503585&r1=503584&r2=503585
==============================================================================
--- webservices/axis2/trunk/java/modules/kernel/src/org/apache/axis2/description/OutInAxisOperation.java (original)
+++ webservices/axis2/trunk/java/modules/kernel/src/org/apache/axis2/description/OutInAxisOperation.java Mon Feb  5 00:21:12 2007
@@ -48,12 +48,12 @@
         //setup a temporary name
         QName tmpName = new QName(this.getClass().getName()+"_"+UUIDGenerator.getUUID());
         this.setName(tmpName);
-        setMessageExchangePattern(WSDL20_2004Constants.MEP_URI_OUT_IN);
+        setMessageExchangePattern(WSDL20_2006Constants.MEP_URI_OUT_IN);
     }
 
     public OutInAxisOperation(QName name) {
         super(name);
-        setMessageExchangePattern(WSDL20_2004Constants.MEP_URI_OUT_IN);
+        setMessageExchangePattern(WSDL20_2006Constants.MEP_URI_OUT_IN);
     }
 
     public void addMessageContext(MessageContext msgContext,

Modified: webservices/axis2/trunk/java/modules/kernel/src/org/apache/axis2/description/OutOnlyAxisOperation.java
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/java/modules/kernel/src/org/apache/axis2/description/OutOnlyAxisOperation.java?view=diff&rev=503585&r1=503584&r2=503585
==============================================================================
--- webservices/axis2/trunk/java/modules/kernel/src/org/apache/axis2/description/OutOnlyAxisOperation.java (original)
+++ webservices/axis2/trunk/java/modules/kernel/src/org/apache/axis2/description/OutOnlyAxisOperation.java Mon Feb  5 00:21:12 2007
@@ -49,13 +49,13 @@
         QName tmpName = new QName(this.getClass().getName()+"_"+UUIDGenerator.getUUID());
         this.setName(tmpName);
         createMessage();
-        setMessageExchangePattern(WSDL20_2004Constants.MEP_URI_OUT_ONLY);
+        setMessageExchangePattern(WSDL20_2006Constants.MEP_URI_OUT_ONLY);
     }
 
     public OutOnlyAxisOperation(QName name) {
         super(name);
         createMessage();
-        setMessageExchangePattern(WSDL20_2004Constants.MEP_URI_OUT_ONLY);
+        setMessageExchangePattern(WSDL20_2006Constants.MEP_URI_OUT_ONLY);
     }
 
     public void addMessage(AxisMessage message, String label) {

Modified: webservices/axis2/trunk/java/modules/kernel/src/org/apache/axis2/description/RobustOutOnlyAxisOperation.java
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/java/modules/kernel/src/org/apache/axis2/description/RobustOutOnlyAxisOperation.java?view=diff&rev=503585&r1=503584&r2=503585
==============================================================================
--- webservices/axis2/trunk/java/modules/kernel/src/org/apache/axis2/description/RobustOutOnlyAxisOperation.java (original)
+++ webservices/axis2/trunk/java/modules/kernel/src/org/apache/axis2/description/RobustOutOnlyAxisOperation.java Mon Feb  5 00:21:12 2007
@@ -39,12 +39,12 @@
         //setup a temporary name
         QName tmpName = new QName(this.getClass().getName()+"_"+UUIDGenerator.getUUID());
         this.setName(tmpName);
-        setMessageExchangePattern(WSDL20_2004Constants.MEP_URI_ROBUST_OUT_ONLY);
+        setMessageExchangePattern(WSDL20_2006Constants.MEP_URI_ROBUST_OUT_ONLY);
     }
 
     public RobustOutOnlyAxisOperation(QName name) {
         super(name);
-        setMessageExchangePattern(WSDL20_2004Constants.MEP_URI_ROBUST_OUT_ONLY);
+        setMessageExchangePattern(WSDL20_2006Constants.MEP_URI_ROBUST_OUT_ONLY);
     }
 
     public OperationClient createClient(ServiceContext sc, Options options) {

Modified: webservices/axis2/trunk/java/modules/kernel/src/org/apache/axis2/description/WSDL11ToAllAxisServicesBuilder.java
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/java/modules/kernel/src/org/apache/axis2/description/WSDL11ToAllAxisServicesBuilder.java?view=diff&rev=503585&r1=503584&r2=503585
==============================================================================
--- webservices/axis2/trunk/java/modules/kernel/src/org/apache/axis2/description/WSDL11ToAllAxisServicesBuilder.java (original)
+++ webservices/axis2/trunk/java/modules/kernel/src/org/apache/axis2/description/WSDL11ToAllAxisServicesBuilder.java Mon Feb  5 00:21:12 2007
@@ -21,18 +21,12 @@
 import java.util.ArrayList;
 import java.util.Iterator;
 import java.util.List;
-import java.util.Map;
-import java.util.Set;
 import java.util.Map.Entry;
 
-import javax.wsdl.Definition;
 import javax.wsdl.Port;
 import javax.wsdl.Service;
-import javax.wsdl.WSDLException;
-import javax.xml.namespace.QName;
 
 import org.apache.axis2.AxisFault;
-import org.apache.axis2.wsdl.WSDLConstants;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 



---------------------------------------------------------------------
To unsubscribe, e-mail: axis-cvs-unsubscribe@ws.apache.org
For additional commands, e-mail: axis-cvs-help@ws.apache.org
--- webservices/axis2/trunk/java/modules/kernel/src/org/apache/axis2/description/AxisService.java (original)
+++ webservices/axis2/trunk/java/modules/kernel/src/org/apache/axis2/description/AxisService.java Mon Feb  5 00:21:12 2007
@@ -72,12 +72,17 @@
  */
 public class AxisService extends AxisDescription {
 
+    private Map endpointMap = new HashMap();
+
     private Map messageNameToOperationsMap = new HashMap();
 
     private int nsCount = 0;
     private static final Log log = LogFactory.getLog(AxisService.class);
     private URL fileName;
 
+    // Maps httpLocations to corresponding operations. Used to dispatch rest messages.    
+    private HashMap httpLocationDispatcherMap = null;
+
     private HashMap operationsAliasesMap = null;
 //    private HashMap operations = new HashMap();
 
@@ -170,7 +175,8 @@
     private NamespaceMap nameSpacesMap;
 
     private String soapNsUri;
-    private String endpoint;
+    private String endpointName;
+    private String endpointURL;
 
     // Flag representing whether WS-Addressing is required to use this service.
     // Reflects the wsaw:UsingAddressing wsdl extension element
@@ -187,8 +193,14 @@
 
     // name of the  binding used : use in codegeneration
     private String bindingName;
-    // name of the port type used : use in codegeneration
-    private String portTypeName;
+
+    public AxisEndpoint getEndpoint(String key) {
+        return (AxisEndpoint)endpointMap.get(key);
+    }
+
+    public void addEndpoint(String key,AxisEndpoint axisEndpoint) {
+        this.endpointMap.put(key,axisEndpoint);
+    }
 
     public String getWSAddressingFlag() {
         return wsaddressingFlag;
@@ -242,6 +254,7 @@
         moduleConfigmap = new HashMap();
         //by default service scope is for the request
         scope = Constants.SCOPE_REQUEST;
+        httpLocationDispatcherMap = new HashMap();
         messageReceivers = new HashMap();
         moduleRefs = new ArrayList();
         engagedModules = new ArrayList();
@@ -254,12 +267,20 @@
         objectSupplier = new DefaultObjectSupplier();
     }
 
+    /**
+     * @deprecated use AxisService#getEndpointName() instead.
+     * @return name of the port type
+     */
     public String getPortTypeName() {
-        return portTypeName;
+        return endpointName;
     }
 
+    /**
+     * @deprecated use AxisService#setEndpointName() instead
+     * @param portTypeName
+     */
     public void setPortTypeName(String portTypeName) {
-        this.portTypeName = portTypeName;
+        this.endpointName = portTypeName;
     }
 
     public String getBindingName() {
@@ -282,14 +303,14 @@
     }
 
     /**
-     * get the endpoint
+     * get the endpointName
      */
-    public String getEndpoint() {
-        return endpoint;
+    public String getEndpointName() {
+        return endpointName;
     }
 
-    public void setEndpoint(String endpoint) {
-        this.endpoint = endpoint;
+    public void setEndpointName(String endpoint) {
+        this.endpointName = endpoint;
     }
 
     /**
@@ -404,7 +425,7 @@
         Iterator axisMessageIter = axisOperation.getChildren();
 
         while (axisMessageIter.hasNext()) {
-            AxisMessage axisMessage = (AxisMessage) axisMessageIter.next();
+            AxisMessage axisMessage = (AxisMessage) axisMessageIter.next();   
             String messageName = axisMessage.getName();
             if (messageName != null && !messageName.equals(operationName)) {
                 mapActionToOperation(messageName, axisOperation);
@@ -437,7 +458,7 @@
     private MessageReceiver loadDefaultMessageReceiver(String mepURL, AxisService service) {
         MessageReceiver messageReceiver;
         if (mepURL == null) {
-            mepURL = WSDLConstants.WSDL20_2004Constants.MEP_URI_IN_OUT;
+            mepURL = WSDLConstants.WSDL20_2006Constants.MEP_URI_IN_OUT;
         }
         if (service != null) {
             messageReceiver = service.getMessageReceiver(mepURL);
@@ -552,6 +573,17 @@
         operationsAliasesMap.put(action, axisOperation);
     }
 
+    /**
+     * Maps an constant string in the whttp:location to the given operation. This is used by
+     * RequestURIOperationDispatcher based dispatching to figure out which operation it is that a
+     * given message is for.
+     *
+     * @param string        the constant drawn from whttp:location
+     * @param axisOperation the operation to map to
+     */
+    public void addHttpLocationDispatcherString(String string, AxisOperation axisOperation) {
+        httpLocationDispatcherMap.put(string, axisOperation);
+    }
 
     public void printSchema(OutputStream out) throws AxisFault {
         for (int i = 0; i < schemaList.size(); i++) {
@@ -709,8 +741,8 @@
             }
         } else {
             setWsdlFound(true);
-            //pick the endpoint and take it as the epr for the WSDL
-            getWSDL(out, new String[]{this.endpoint}, "services");
+            //pick the endpointName and take it as the epr for the WSDL
+            getWSDL(out, new String[]{this.endpointName}, "services");
         }
     }
 
@@ -790,8 +822,8 @@
             }
         } else {
             setWsdlFound(true);
-            //pick the endpoint and take it as the epr for the WSDL
-            getWSDL2(out, new String[]{this.endpoint});
+            //pick the endpointName and take it as the epr for the WSDL
+            getWSDL2(out, new String[]{this.endpointName});
         }
     }
 
@@ -1281,7 +1313,7 @@
                 new WSDL11ToAxisServiceBuilder(wsdlDefinition, wsdlServiceName, portName);
         serviceBuilder.setServerSide(false);
         AxisService axisService = serviceBuilder.populateService();
-        options.setTo(new EndpointReference(axisService.getEndpoint()));
+        options.setTo(new EndpointReference(axisService.getEndpointName()));
         options.setSoapVersionURI(axisService.getSoapNsUri());
         return axisService;
     }
@@ -1831,5 +1863,17 @@
 
     public void addmessageNameToOperationMapping(String messageName, AxisOperation operation) {
         messageNameToOperationsMap.put(messageName, operation);
+    }
+
+    public String getEndpointURL() {
+        return endpointURL;
+    }
+
+    public void setEndpointURL(String endpointURL) {
+        this.endpointURL = endpointURL;
+    }
+
+    public Map getEndpoints() {
+        return endpointMap;
     }
 }

Modified: webservices/axis2/trunk/java/modules/kernel/src/org/apache/axis2/description/AxisService2OM.java
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/java/modules/kernel/src/org/apache/axis2/description/AxisService2OM.java?view=diff&rev=503585&r1=503584&r2=503585
==============================================================================